@@ -21,7 +21,7 @@ class ProcessorTest < Minitest::Spec
       after { clean_remove_const(:SteppingExample) }
 
       it "stops execution at the first line after binding.pry" do
-        output.string.must_match(/\=>  8:/)
+        _(output.string).must_match(/\=>  8:/)
       end
     end
 
@@ -33,7 +33,7 @@ class ProcessorTest < Minitest::Spec
       end
 
       it "stops execution at the first line after binding.pry" do
-        output.string.must_match(/\=>  9:/)
+        _(output.string).must_match(/\=>  9:/)
       end
     end
   end
